==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/listener/IngressListenerConfigurationFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface IngressListenerConfigurationFluent<A extends IngressListenerConfigurationFluent<A>> extends KafkaListenerExternalConfigurationFluent<A>{


    
/**
 * This method has been deprecated, please use method buildBootstrap instead.
 * @return The buildable object.
 */
@Deprecated public IngressListenerBootstrapConfiguration getBootstrap();
    public IngressListenerBootstrapConfiguration buildBootstrap();
    public A withBootstrap(IngressListenerBootstrapConfiguration bootstrap);
    public Boolean hasBootstrap();
    public IngressListenerConfigurationFluent.BootstrapNested<A> withNewBootstrap();
    public IngressListenerConfigurationFluent.BootstrapNested<A> withNewBootstrapLike(IngressListenerBootstrapConfiguration item);
    public IngressListenerConfigurationFluent.BootstrapNested<A> editBootstrap();
    public IngressListenerConfigurationFluent.BootstrapNested<A> editOrNewBootstrap();
    public IngressListenerConfigurationFluent.BootstrapNested<A> editOrNewBootstrapLike(IngressListenerBootstrapConfiguration item);
    public A addToBrokers(int index,IngressListenerBrokerConfiguration item);
    public A setToBrokers(int index,IngressListenerBrokerConfiguration item);
    public A addToBrokers(IngressListenerBrokerConfiguration... items);
    public A addAllToBrokers(Collection<IngressListenerBrokerConfiguration> items);
    public A removeFromBrokers(IngressListenerBrokerConfiguration... items);
    public A removeAllFromBrokers(Collection<IngressListenerBrokerConfiguration> items);
    public A removeMatchingFromBrokers(io.fabric8.kubernetes.api.builder.Predicate<IngressListenerBrokerConfigurationBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildBrokers instead.
 * @return The buildable object.
 */
@Deprecated public List<IngressListenerBrokerConfiguration> getBrokers();
    public List<IngressListenerBrokerConfiguration> buildBrokers();
    public IngressListenerBrokerConfiguration buildBroker(int index);
    public IngressListenerBrokerConfiguration buildFirstBroker();
    public IngressListenerBrokerConfiguration buildLastBroker();
    public IngressListenerBrokerConfiguration buildMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<IngressListenerBrokerConfigurationBuilder> predicate);
    public Boolean hasMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<IngressListenerBrokerConfigurationBuilder> predicate);
    public A withBrokers(List<IngressListenerBrokerConfiguration> brokers);
    public A withBrokers(IngressListenerBrokerConfiguration... brokers);
    public Boolean hasBrokers();
    public IngressListenerConfigurationFluent.BrokersNested<A> addNewBroker();
    public IngressListenerConfigurationFluent.BrokersNested<A> addNewBrokerLike(IngressListenerBrokerConfiguration item);
    public IngressListenerConfigurationFluent.BrokersNested<A> setNewBrokerLike(int index,IngressListenerBrokerConfiguration item);
    public IngressListenerConfigurationFluent.BrokersNested<A> editBroker(int index);
    public IngressListenerConfigurationFluent.BrokersNested<A> editFirstBroker();
    public IngressListenerConfigurationFluent.BrokersNested<A> editLastBroker();
    public IngressListenerConfigurationFluent.BrokersNested<A> editMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<IngressListenerBrokerConfigurationBuilder> predicate);

    public interface BootstrapNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressListenerBootstrapConfigurationFluent<IngressListenerConfigurationFluent.BootstrapNested<N>>{

        
    public N and();    public N endBootstrap();
}
    public interface BrokersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressListenerBrokerConfigurationFluent<IngressListenerConfigurationFluent.BrokersNested<N>>{

        
    public N and();    public N endBroker();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/listener/IngressListenerConfigurationFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface IngressListenerConfigurationFluent<A extends IngressListenerConfigurationFluent<A>> extends KafkaListenerExternalConfigurationFluent<A>{


    
/**
 * This method has been deprecated, please use method buildBootstrap instead.
 * @return The buildable object.
 */
@Deprecated public IngressListenerBootstrapConfiguration getBootstrap();
    public IngressListenerBootstrapConfiguration buildBootstrap();
    public A withBootstrap(IngressListenerBootstrapConfiguration bootstrap);
    public Boolean hasBootstrap();
    public IngressListenerConfigurationFluent.BootstrapNested<A> withNewBootstrap();
    public IngressListenerConfigurationFluent.BootstrapNested<A> withNewBootstrapLike(IngressListenerBootstrapConfiguration item);
    public IngressListenerConfigurationFluent.BootstrapNested<A> editBootstrap();
    public IngressListenerConfigurationFluent.BootstrapNested<A> editOrNewBootstrap();
    public IngressListenerConfigurationFluent.BootstrapNested<A> editOrNewBootstrapLike(IngressListenerBootstrapConfiguration item);
    public A addToBrokers(int index,IngressListenerBrokerConfiguration item);
    public A setToBrokers(int index,IngressListenerBrokerConfiguration item);
    public A addToBrokers(IngressListenerBrokerConfiguration... items);
    public A addAllToBrokers(Collection<IngressListenerBrokerConfiguration> items);
    public A removeFromBrokers(IngressListenerBrokerConfiguration... items);
    public A removeAllFromBrokers(Collection<IngressListenerBrokerConfiguration> items);
    public A removeMatchingFromBrokers(io.fabric8.kubernetes.api.builder.Predicate<IngressListenerBrokerConfigurationBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildBrokers instead.
 * @return The buildable object.
 */
@Deprecated public java.util.List<IngressListenerBrokerConfiguration> getBrokers();
    public java.util.List<IngressListenerBrokerConfiguration> buildBrokers();
    public IngressListenerBrokerConfiguration buildBroker(int index);
    public IngressListenerBrokerConfiguration buildFirstBroker();
    public IngressListenerBrokerConfiguration buildLastBroker();
    public IngressListenerBrokerConfiguration buildMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<IngressListenerBrokerConfigurationBuilder> predicate);
    public Boolean hasMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<IngressListenerBrokerConfigurationBuilder> predicate);
    public A withBrokers(java.util.List<IngressListenerBrokerConfiguration> brokers);
    public A withBrokers(IngressListenerBrokerConfiguration... brokers);
    public Boolean hasBrokers();
    public IngressListenerConfigurationFluent.BrokersNested<A> addNewBroker();
    public IngressListenerConfigurationFluent.BrokersNested<A> addNewBrokerLike(IngressListenerBrokerConfiguration item);
    public IngressListenerConfigurationFluent.BrokersNested<A> setNewBrokerLike(int index,IngressListenerBrokerConfiguration item);
    public IngressListenerConfigurationFluent.BrokersNested<A> editBroker(int index);
    public IngressListenerConfigurationFluent.BrokersNested<A> editFirstBroker();
    public IngressListenerConfigurationFluent.BrokersNested<A> editLastBroker();
    public IngressListenerConfigurationFluent.BrokersNested<A> editMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<IngressListenerBrokerConfigurationBuilder> predicate);

    public interface BootstrapNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressListenerBootstrapConfigurationFluent<IngressListenerConfigurationFluent.BootstrapNested<N>>{

        
    public N and();    public N endBootstrap();
}
    public interface BrokersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressListenerBrokerConfigurationFluent<IngressListenerConfigurationFluent.BrokersNested<N>>{

        
    public N and();    public N endBroker();
}


}
